@@ -22,8 +22,10 @@ from ptah.uri import extract_uri_schema
 from ptah.uri import UriFactory
 
 # sqla
+from ptah.sqlautils import sa_session
 from ptah.sqlautils import get_base
 from ptah.sqlautils import get_session
+from ptah.sqlautils import get_session_maker
 from ptah.sqlautils import reset_session
 
 # events
@@ -33,6 +35,7 @@ from ptah.events import event
 # view api
 from ptah.view import View
 from ptah.view import add_message
+from ptah.view import render_message
 from ptah.view import render_messages
 
 from ptah.view import snippet
@@ -50,6 +53,7 @@ from ptah.library import render_includes
 # settings
 from ptah.settings import get_settings
 from ptah.settings import register_settings
+from ptah.settings import load_dbsettings
 
 # security
 from ptah.authentication import auth_service
@@ -116,9 +120,11 @@ from ptah.util import tldata
 from ptah.rst import rst_to_html
 
 # sqlalchemy utils
+from ptah.sqlautils import transaction
 from ptah.sqlautils import QueryFreezer
 from ptah.sqlautils import JsonDictType
 from ptah.sqlautils import JsonListType
+from ptah.sqlautils import set_jsontype_serializer
 from ptah.sqla import generate_fieldset
 from ptah.sqla import build_sqla_fieldset
 
@@ -246,3 +252,5 @@ def includeme(cfg):
 
     # scan ptah
     cfg.scan('ptah')
+
+    cfg.add_translation_dirs('ptah:locale')
