@@ -5,6 +5,7 @@ import threading
 import pkg_resources
 from docutils import io
 from docutils.core import Publisher
+from pyramid.compat import text_type, bytes_
 
 from sphinx.application import Sphinx
 from sphinx.writers.html import HTMLWriter, HTMLTranslator
@@ -14,7 +15,7 @@ local_data = threading.local()
 
 tempdir = tempfile.mkdtemp()
 tmp = open(os.path.join(tempdir, 'conf.py'), 'wb')
-tmp.write('# -*- coding: utf-8 -*-')
+tmp.write(bytes_('# -*- coding: utf-8 -*-'))
 tmp.close()
 
 
@@ -46,8 +47,8 @@ def get_sphinx():
 
 
 def rst_to_html(text):
-    if not isinstance(text, unicode):
-        text = unicode(text, 'utf-8')
+    if not isinstance(text, text_type):
+        text = text_type(text)
 
     sphinx, pub = get_sphinx()
 
@@ -56,20 +57,20 @@ def rst_to_html(text):
     try:
         pub.publish()
     except:
-        log.warning(u'ReST to HTML error\n %s', text)
-        return u'<pre>%s</pre>' % text
+        log.warning('ReST to HTML error\n %s', text)
+        return '<pre>%s</pre>' % text
 
     doctree = pub.document
     sphinx.env.filter_messages(doctree)
-    for domain in sphinx.env.domains.itervalues():
+    for domain in sphinx.env.domains.values():
         domain.process_doc(sphinx.env, 'text', doctree)
 
     pub.writer.write(doctree, io.StringOutput(encoding='unicode'))
     pub.writer.assemble_parts()
 
     parts = pub.writer.parts
-    return u''.join((parts['body_pre_docinfo'],
-                     parts['docinfo'], parts['body']))
+    return ''.join((parts['body_pre_docinfo'],
+                    parts['docinfo'], parts['body']))
 
 
 class CustomHTMLTranslator(HTMLTranslator):
